{% extends "base.html" %}
{% load timepiece_tags markup %}

{% block title %}{{ business.name }}{% endblock %}

{% block content %}
<h2>{{ business.name }}</h2>
<ul class='header-actions-left'>
{% if perms.timepiece.change_business %}
	<li><a href='{% url edit_business business.pk %}'>Edit business</a></li>
{% endif %}
</ul>
<table class='vertical'>
    <tr>
        <th>Email:</th>
        <td>{{ business.email }}</td>
    </tr>
    <tr>
        <th>Description:</th>
        <td>{{ business.description|textile }}</td>
    </tr>
    <tr>
        <th>Notes:</th>
        <td>{{ business.notes|textile }}</td>
    </tr>
</table>
{% endblock %}
