{% extends "base.html" %}
{% block title %}{% if not person %}Create Person{% else %}Edit {{ person }}{% endif %}{% endblock %}

{% block content %}

<h2>{% if not person %}Create Person{% else %}Edit {{ person.name }}{% endif %}</h2>

<form id="create-edit-person" action="" method="post" accept-charset="utf-8">
    {% csrf_token %}
    <table class='vertical'>
    {{ person_form }}
    <td>&nbsp;</td>
    <td class="submit">
    <input type="button" onclick="history.go(-1)" value="Cancel">
    <input type="submit" value="Save →" name="submit">
    </td>
    </table>
</form>

{% endblock %}
