{% extends 'timepiece/time-sheet/base.html' %}

{% block title %}{% if entry %}Update{% else %}Create{% endif %} Entry{% endblock %}

{% block content %}
<h2>{% if entry %}Update{% else %}Create{% endif %} Entry</h2>
<form action="" method="post">
    {% csrf_token %}
    <table class='vertical'>
        {{ form }}
        <tr>
            <td>&nbsp;</td>
            <td class='submit'>
                <input type='button' value='Cancel' onclick='history.go(-1)' />
                &nbsp;
                <input type='submit' name='submit' value='Save &rarr;' />
            </td>
        </tr>
    </table>
</form>
{% endblock %}
