{% extends 'timepiece/time-sheet/base.html' %}

{% block content %}
<h2>Clock Out of Project</h2>
<form id="general-entry" action="" method="post" accept-charset="utf-8">
    {% csrf_token %}
    <table class='vertical'>
        {{ form }}
        <tr>
            <td>&nbsp;</td>
            <td class='submit'>
                <input type='button' value='Cancel' onclick='history.go(-1)' />
                &nbsp;
                <input type='submit' name='submit' value='Clock Out &rarr;' />
            </td>
        </tr>
    </table>
</form>
{% endblock %}
