/*body, p, td, th {
    font-family: Calibri, Tahoma, "Trebuchet MS", Verdana, Arial;
    font-size: 1.3em;
    color: #333;
}

body {
    background-color: #eee;
    margin-top: 0px;
}
*/

ul.actions {
    margin: 0;
    font-size: 93%;
}

ul.actions li {
    display: inline;
    border-left: 1px solid lightgray;
    padding: 0 0.2em 0 0.5em;
}

ul.actions li:first-child {
    padding: 0 0.2em 0 0;
    border-left: none;
}

textarea#id_comments {
    width: 30em;
}

input[type='text'].timepiece-time {
    width: 8em;
}

#id_start_time_0 {
    margin-right: 1em;
}
#id_end_time_0 {
    margin-right: 1em;
}

td.hours{
    text-align: right;
}

/*th, td {
    padding: 0.2em; 
}

table {
    width: 100%;
    border-spacing: 1px;
    border: 1px solid #555;
    margin: 5px 0px;
}
th {
    background-color: #7ba5bd;
    border: 1px solid #51809b;
}
td {
    vertical-align: top;
}

a { color: #b5328f; }
a:hover { text-decoration: none; color: #a00; }

#django-messages {
    width: 80%;
    margin: 10px auto;
    padding: 0.5em;
    border: 1px solid #b5328f;
    background-color: #f3daec;
    font-size: 1.3em;
    text-align: center;
}
#django-messages ul,
#django-messages li {
    list-style-type: none;
    margin: 0px;
    padding: 0px;
}

#pendulum-controls { text-align: right; }
ul.pendulum-controls {
    margin: 0px 0px 10px;
    padding: 0px;
}
ul.pendulum-controls li { display: inline; }
ul.pendulum-controls li a {
    font-weight: bold;
    padding: 5px;
    border: 1px outset #444;
    background-color: #a7cade;
    text-decoration: none;
}
ul.pendulum-controls li a:hover {
    background-color: #2c566f;
    color: #fff;
    border-style: inset;
}

#container {
    width: 50em;
    margin: auto;
    background-color: #fff;
    border: solid #333;
    border-width: 0px 2px 2px;
    padding: 0.5 2em 2em;
}
#footer {
    text-align: center;
    font-size: 0.8em;
}

#entry-table .odd td,
.entry-statistics .odd td,
.clock-in .odd td {
    background-color: #deecf4;
    border: 1px solid #c3d1d9;
}
#entry-table .even td,
.entry-statistics .even td,
.clock-in .even td {
    background-color: #bad1de;
    border: 1px solid #97b2c1;
}
.entry-statistics table { margin: 0px; }

#entry-table .day-summary td,
#entry-table .week-summary td {
    background-color: #7ba5bd;
    border: 1px solid #51809b;
    font-size: 0.8em;
}

#entry-table .entry-date,
#entry-table .entry-start,
#entry-table .entry-end,
#entry-table .entry-hours,
#entry-table .entry-paused,
#entry-table .entry-project,
#entry-table .entry-activity,
#entry-table .entry-admin { text-align: center; }
*/
