{% extends "base.html" %}
{% load timepiece_tags markup %}

{% block title %}{{ person.first_name }} {{ person.last_name }}{% endblock %}

{% block content %}
<h2>{{ person.first_name }} {{ person.last_name }}</h2>
<ul class='header-actions-left'>
{% if perms.auth.change_person %}
	<li><a href='{% url edit_person person.pk %}'>Edit Person</a></li>
{% endif %}
</ul>
<table class='vertical'>
		<tr><th>Username</th><td>{{ person.username }}</td></tr>
		<tr><th>First Name</th><td>{{ person.first_name }}</td></tr>
		<tr><th>Last Name</th><td>{{ person.last_name }}</td></tr>
    <tr>
        <th>Email:</th>
        <td>{{ person.email }}</td>
    </tr>
</table>
{% endblock %}
