{% extends 'timepiece/time-sheet/base.html' %}

{% block title %}Delete Entry{% endblock %}

{% block content %}
<h2>Delete Entry</h2>
<form action="{% url timepiece-delete entry.id %}" method="post">
    {% csrf_token %}
    <h3>Are you sure you want to delete this entry?</h3>
    <br />
    <input type="submit" value="Yes" />
    <input type="button" value="No" onclick="javascript:history.go(-1)" />
    <input type="hidden" name="key" value="{{ entry.delete_key }}" />
</form>
{% endblock %}
