{% extends 'timepiece/time-sheet/base.html' %}

{% block title %}Person Timesheets{% endblock %}

{% block content %}

<h2>Project Timesheets ({{ time_sheets.count }} total)</h2>
<ul class='header-actions-left'>

</ul>

<table class='projects'>
    <tr>
        <th>Name</th>
        <th>Business</th>
        <th>Hours</th>
    </tr>
    {% for sheet in time_sheets %}
    <tr>
        <td><a href='{% url project_time_sheet sheet.project__id %}'>{{ sheet.project__name }}</a></td>
        <td>{{ sheet.project__business__name }}</td>
        <td>{{ sheet.total_hours }}</td>
    </tr>
    {% empty %}
    <tr>
        <td colspan='3'>No time sheets found.</td>
    </tr>
    {% endfor %}
</table>

{% endblock %}
