/* ----------------------------------------------------------------------------
# $Id$
# ----------------------------------------------------------------------------
#
#    Copyright (C) 2008 Caktus Consulting Group, LLC
#
#    This file is part of minibooks.
#
#    minibooks is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of 
#    the License, or (at your option) any later version.
#    
#    minibooks is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#    
#    You should have received a copy of the GNU Affero General Public License
#    along with minibooks.  If not, see <http://www.gnu.org/licenses/>.
*/


html {
	background: white;
}

a {
	color: #0000EE;
	text-decoration: none;
}

a:hover {
	text-decoration: underline;
}

h1,h2,h3,h4,h5,h6 {
	color: #593E1A;
	margin: 1em 0 0 0;
}

h2 {
	border-bottom: 1px solid #593E1A;
}

h2.skinny {
	width: 60%;
}

th {
	text-align: left;
}

div#header-wrapper div#header {
	text-align: left;
}

div#header-wrapper div#header h1 {
	margin: 0;
	padding: 0.7em;
	font-size: 182%;
	font-family: Helvetica;
	letter-spacing: 0.2em;
	font-weight: normal;
	text-decoration: underline;
	color: #FFD800;
	width: 35%;
}

div#header-wrapper div#header a {
	color: #FFD800;
}

div#header-wrapper div#header img#minibooks-logo {
    float: left;
}

ul#quick-search-area {
    float: right;
}

div#header div#header-sidebar {
	float: right;
	margin: 0.5em;
	width: 36em;
}

div#header ul {
	list-style: none;
	font-size: 95%;
	text-align: right;
	margin: 0;
}

div#header ul li {
	display: inline;
}

div#header li#search-menu-item {
	float: right;
	color: white;
}

div#menu-wrapper {
	float: left;
	width: 100%;
	background-color: #593E1A;
	border-bottom: 8px solid #4D669E;
}

div#menu-wrapper div#menu {
	width: 90%;
	margin: 0 auto;
	white-space: nowrap;
}

div#menu-wrapper #menu ul {
	border-left: 1px solid #473014;
	margin: 0;
	padding: 0;
	list-style: none;
	float: left;
	width: 100%;
}

div#menu-wrapper #menu li { display: inline; }

div#menu-wrapper #menu a:link, #menu a:visited {
	padding: 0.5em 1em;
	background: transparent;
	color: #FFD800;
	text-decoration: none;
	float: left;
	border-right: 1px solid #473014;
}

div#menu-wrapper #menu a.active {
	color: white;
	background-color: #4D669E;
}

div#menu-wrapper #menu a:hover {
	text-decoration: underline;
	color: white;
/*  background-color: #4D669E;*/
	background-color: #4D669E;
}

div#content-wrapper {
	border-left: 8px solid #4D669E;
	clear: both;
}

div#content-wrapper div#content {
	width: 95%;
	margin: 0 auto;
	padding: 0.5em 0 0.5em 0;
	clear: both;
	background-color: white;
}

div#footer-wrapper div#footer {
	padding: 0.5em 1em 0.5em 0;
	color: white;
	font-size: 85%;
	text-align: right;
	background-color: #4D669E;
}

div#footer-wrapper div#footer a {
	color: #FFD800;
}

div#sidebar {
	float: right;
	border-bottom: 1px solid #F6F6F6;
	border-left: 1px solid #F6F6F6;
	padding: 0 1em 0 1em;
	width: auto;
}

div#sidebar h3 {
	margin-top: 0;
}

div#floating-sidebar {
	right: 10px;
	border-bottom: 1px solid #F6F6F6;
	border-left: 1px solid #F6F6F6;
	padding: 1em;
	white-space: nowrap;
}

div#floating-sidebar div#reconcile {
	font-size: 12pt;
}

div#floating-sidebar span.label {
	font-weight: bold;
}

div#floating-sidebar div.help-text {
	color: #aaa;
	font-size: 80%;
}

p#remove-account-warning {
	width: 35em;
	margin-top: 1em;
}

#content #left-panel {
	float: left;
	margin: 0;
	padding:0;
	width: 50%;
}

#content #inner-left-panel {
	padding-right: 1.5em;
}

#content #right-panel {
	float: right;
	margin:0;
	padding:0;
	width:50%;
}

#content #inner-right-panel {
	padding-left: 1.5em;
	border-left: 1px solid #ddd;
}

.cleaner {
	clear:both;
	height:1px;
	font-size:1px;
	border:none;
	margin:0;
	padding:0;
	background:transparent;
}

ul#site-utils li {
	display: inline;
	border-left: 1px solid lightgray;
	padding: 0 0.2em 0 0.5em;
}

ul#site-utils li:first-child {
	padding: 0 0.2em 0 0;
	border-left: none;
}

.right {
	float: right;
}

ul.header-actions-left {
	margin: 0.2em 0 1em 0;
	font-size: 93%;
}

ul.header-actions-left li {
	display: inline;
	border-left: 1px solid lightgray;
	padding: 0 0.2em 0 0.5em;
}

ul.header-actions-left li:first-child {
	padding: 0 0.2em 0 0;
	border-left: none;
}

ul.errorlist {
	margin: 0 0 1em 0;
	background-color: lightyellow;
	font-size: 90%;
}

ul.errorlist li {
	padding: 0.5em;
	border-right: 1px solid #aaa;
	border-bottom: 1px solid #aaa;
	border-left: 1px solid #ddd;
	border-top: 1px solid #ddd;
}

table tr td ul.errorlist {
	margin: 0;
}

ul#filters {
	margin-left: 20em;
}

span.individual {
    background: url('../images/icons/user.png') no-repeat;
    padding-left: 20px;
}

span.business {
    background: url('../images/icons/building.png') no-repeat;
    padding-left: 20px;
}

span.project {
    background: url('../images/icons/report.png') no-repeat;
    padding-left: 20px;
}

ul.people li {
	list-style-image: url('../images/icons/user.png');
}

ul.people li.add {
	padding-top: 1em;
	list-style-image: url('../images/icons/user_add.png');
}

ul.businesses li {
	list-style-image: url('../images/icons/building.png');
	padding: 0.2em;
}

ul.projects li {
	list-style-image: url('../images/icons/report.png');
	padding: 0.2em;
}

form table td {
	border: none;
}

table.vertical th {
	text-align: right;
}

table.vertical td.submit {
	text-align: right;
}

table.alternating-rows td {
	border: none;
}

ul#ledger-date-fieldlist {
	list-style-type: none;
	margin-left: 0;
}

ul#ledger-date-fieldlist li {
	display: inline;
}

ul#ledger-date-fieldlist li label {
	font-weight: bold;
}

ul.message_list {
	margin: 0.75em;
	border: 1px solid #CCC;
	background-color: #F8F8F8;
	padding: 0.5em 0.5em 0 0.5em;
}

ul.message_list li {
	padding-bottom: 0.5em;
	list-style-position: inside;
	list-style-image: url('../images/icons/information.png');
	list-style-type: circle;
}

table#accounts {
	width: 70%;
}

table.horizontal th {
	text-align: center;
}

table.vertical th {
	text-align: right;
}

table.vertical.top th {
	vertical-align: top;
}

table th {
	font-weight: bold;
}

table.vertical td textarea#id_message {
	width: 30em;
	height: 16em;
	font-size: 100%;
}

table.horizontal td, table.horizontal th,
table.vertical td, table.vertical th {
	padding: 0.5em;
}

table.vertical td.remove img {
	vertical-align: middle;
}

table.vertical td.remove a:hover {
	text-decoration: none;
}

.submit input {
	font-size: 110%;
	margin: 1em 0.5em 1em 0;
}

form#date-filter table {
	margin: 0;
}

form#date-filter input[name=from_date],
form#date-filter input[name=date],
form#date-filter input[name=to_date] {
	width: 7em;
}

form#login {
	margin-top: 1em;
}

form#login input[name=email] {
	width: 20em;
}

form#login input[name=password] {
	width: 10em;
}

form.modify-pagelet textarea[name=content] {
	width: 50em;
	height: 30em;
}

form#create-edit-business {
	margin-top: 1em;
}

form#create-edit-business table input[name=name] {
	width: 20em;
}

form#create-edit-business table textarea[name=notes] {
	width: 20em;
	height: 5em;
}

form#create-edit-business table textarea[name=street] {
	width: 20em;
	height: 5em;
}

form#create-edit-business table input[name=zip] {
	width: 5em;
}

form#create-edit-business ul {
	margin: 0;
	padding: 0.2em;
}

form#create-edit-business li {
	padding-top: 0.3em;
	list-style-type: none;
	list-style-position: outside;
}

form#create-edit-exchange table input.calendar {
	width: 6em;
}

form#create-edit-exchange table textarea#id_memo {
	width: 30em;
	height: 10em;
}

form#create-edit-exchange td.count input {
	width: 4em;
}

form#create-edit-exchange td.rate input {
	width: 4em;
}

form#create-edit-exchange td.reconciled input[type=checkbox] {
	margin: 0 0.2em;
}

form#quick-search-form {
	margin-right: 1em;
	padding-top: 10px;
}

form#quick-search-form table {
	margin: 0;
}

form#quick-search-form table td input#id_quick_search_text[name=quick_search_text] {
  padding: 0.2em;
  width: 20em;
  font-size: 150%;
  background-color: #b9c3dc;
  border: 1px #eee solid;
  color: #0a2666;
}

form#quick-search-form table th label {
  font-size: 150%;
  color: #b9c3dc;
}

form.search ul {
	height: 2em;
}

form.search ul li {
	display: inline;
	vertical-align: center;
}

form.search ul li label {
	font-weight: bold;
	padding-right: 0.5em;
}

form.search ul li input#id_search {
	width: 25em;
	font-size: 110%;
}

form.search ul li.form-buttons input {
	font-size: 105%;
}

form#exchange-email table textarea[name=memo],
form#project-report-email table textarea[name=memo] {
	width: 35em;
	height: 15em;
}

form#project-report-email {
	margin-top: 1em;
}

form#create-edit-person table textarea#id_notes {
	width: 30em;
	height: 10em;
}

form#create-edit-person table input[name=first_name] {
	width: 16em;
}

form#create-edit-person table input[name=last_name] {
	width: 16em;
}

form#create-edit-person table input[name=email] {
	width: 16em;
}

form#add-contact input[name=search] {
	width: 16em;
}

form#create-edit-account {
	margin-top: 1em;
}

form#create-edit-account table input[name=name] {
	width: 16em;
}

form#create-edit-account table input[name=number] {
	width: 4em;
}

form input[name=date] {
	width: 7em;
}

form input[name=amount] {
    width: 8em;
}

form  textarea[name=memo] {
	width: 35em;
	height: 15em;
}

form input[name=quantity ] {
    width: 8em;
}

div#remove-message {
	margin: 1em 0em;
}

form .field-wrapper {
	padding: 1em 0.1em 0.5em 0.1em;
}

form .field-wrapper label {
	font-weight: bold;
}

form#transfer-funds input[name=date] {
    width: 6em;
}

form#transfer-funds input[name=amount] {
    width: 8em;
}

form#create-edit-interaction input[name=date] {
	width: 7em;
}

form#create-edit-interaction textarea[name=memo] {
	width: 35em;
	height: 15em;
}

form#create-edit-project textarea[name=description] {
	width: 35em;
	height: 15em;
}

form#create-edit-interaction input[name=search] {
	margin: 1em 1em 0 0;
}

form#edit-project-relationship ul {
	margin: 0.5em 0;
}

form#edit-project-relationship ul li {
	list-style: none;
	
}


caption {
	font-weight: bold;
}

table#ledger_accounts {
	max-width: 75%;
}

table#recent-exchanges {
	background-color: #F4FAFF;
	font-size: 100%;
	border-top: 1px solid lightgray;
}

table#recent-exchanges td {
	padding: 0.2em 0.5em;
	border: none;
	border-bottom: 1px solid lightgray;
}

table#recent-exchanges span.exchange-type {
	color: gray;
	font-size: 85%;
}

table#exchanges td.show-all,
table#exchanges th.type {
	font-weight: normal;
	border: none;
}

table#person-profile {
	float: right;
	max-width: 40em;
}

/* account ledger style */

table.vertical table.horizontal th {
    text-align: center;
}

td {
	border: 1px solid #eee;
}

TH.ledger {
	font-weight: bold;
	padding: 0.2em;
	margin: 0.3em;
	text-align: center;
}

TH.ledger.account-name {
	padding-top: 2em;
	font-size: 120%;
	text-align: left;
	color: #593E1A;
	border-bottom: 1px solid #593E1A;
}

TH.ledger.memo {
	text-align: left;
}

TH.ledger.date {
	width: 7em;
}

TH.ledger.business {
	width: 15em;
}

TD.ledger.number.total {
	width: 6em;
}

TD.ledger.reconciled {
	padding: 0 0.4em;
	text-align: center;
}

TD.ledger {
	padding: 0.2em;
	margin: 0.3em;
	text-align: left;
}

TH.ledger.number {
	text-align: center;
}

TD.ledger.number {
	text-align: right;
}

TD.ledger:first-child {
}

TD.ledger.memo {
	
	white-space: nowrap;
}

TD.ledger.account-balance,
TD.ledger.delivered,
TD.ledger.links {
	padding: 0.5em 0.3em 0.2em 0.3em;
}

TD.ledger.links {
	text-align: center;
}

TH.ledger.account-balance {
	text-align: right;
}

TD.ledger.links a {
	text-align: center;
	margin: 0.2em;
}

table.people td.name,
table.people td.phone {
	white-space: nowrap;
}

span.trac-options {
  font-size: 90%;
}

ul ul,
ul ul ul
{
	margin-top: 0;
	margin-bottom: 0;
}

table#list-interactions tr.date-type td {
	border-top: 1px solid #EEE;
	padding-top: 1em;
}

table#list-interactions tr td.ledger.date h3,
table#list-interactions .header-actions-left {
	margin: 0;
}

table#list-interactions tr.body td {
	vertical-align: top;
}

table#list-interactions td {
	border: none;
}

table#list-interactions td.memo {
	padding-left: 2em;
}

table#list-interactions td.date,
table#list-interactions td.project {
	white-space: nowrap;
}

table#profit-loss tr td {
	border: none;
}

tr.o td {
	background-color: #F8F8F8;
}

ul.date-filters {
	margin: 1em 0;
}

ul.date-filters li {
	list-style-type: none;
}

ul.date-filters ul {
	margin: 0.2em 0;
	font-size: 93%;
}

ul.date-filters ul li {
	display: inline;
	border-left: 1px solid lightgray;
	padding: 0 0.2em 0 0.5em;
}

ul.date-filters ul li:first-child {
	padding: 0 0.2em 0 0;
	border-left: none;
}

ul.date-filters ul li.label {
	font-weight: bold;
}

ul.reports {
	font-size: 110%;
}

ul.reports li {
	list-style-image: url('../images/icons/chart_bar.png');
	margin-bottom: 0.5em;
}

img.icon {
	padding-right: 0.5em;
	height:16px;
	width:16px;
}

/** pagination **/
.pagination {
	padding: 1em;
}
 
.pagination .disabled,
.pagination .disabled {
	color: #aaa;
	padding: 0.3em;
	border: 1px solid #aaa;
}
 
.pagination a.prev, .pagination a:visited.prev,
.pagination a.next, .pagination a:visited.next {
	border: 1px solid #98D0FD;
	background-color: #D0E9FD;
	color: #234f32;
	padding: 0.3em;
}
 
.pagination a.page, .pagination a:visited.page, .pagination .current {
	padding: 0.25em;
	margin: 0em 0.25em;
	border: 1px solid #98D0FD;
	background-color: #D0E9FD;
	color:#006000;
}
 
.pagination .current {
	font-size: 125%;
	font-weight: bold;
	color: black;
}
 
.pagination a:hover.page,
.pagination a:hover.curr,
.pagination a:hover.prev,
.pagination a:hover.next {
	color: #000;
	background-color: white;
	border: 1px solid #98D0FD;
}

#ui-datepicker-div {
	font-size: 80%;
}

#activity-summary, #project-summary, #person-summary {
    float: left;
    margin-right: 1em;
    min-width: 13em;
}

input.crm-date-field {
    width: 7em;
}

.active.paused, #active-entries .paused {
    color: #999;
}

.active {
    color: #000080;
}

div.snippet pre.code a {
    display:block;
}

form.snippetform ol li {
    list-style: none;
}

form.snippetform textarea{
    width: 100%;
    height: 400px;
}

tr.overtime td {
    color: red;
}

tr.non-billable td {
    color: #888;
}

table#projection th {
    color: #888;
}

table#projection th.contract {
    color: #000;
}

td.assigned, td.worked, td.allocated {
    color: #888;
}

.hll { background-color: #ffffcc }
.c { color: #808080 } /* Comment */
.err { color: #F00000; background-color: #F0A0A0 } /* Error */
.k { color: #008000; font-weight: bold } /* Keyword */
.o { color: #303030 } /* Operator */
.cm { color: #808080 } /* Comment.Multiline */
.cp { color: #507090 } /* Comment.Preproc */
.c1 { color: #808080 } /* Comment.Single */
.cs { color: #cc0000; font-weight: bold } /* Comment.Special */
.gd { color: #A00000 } /* Generic.Deleted */
.ge { font-style: italic } /* Generic.Emph */
.gr { color: #FF0000 } /* Generic.Error */
.gh { color: #000080; font-weight: bold } /* Generic.Heading */
.gi { color: #00A000 } /* Generic.Inserted */
.go { color: #808080 } /* Generic.Output */
.gp { color: #c65d09; font-weight: bold } /* Generic.Prompt */
.gs { font-weight: bold } /* Generic.Strong */
.gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.gt { color: #0040D0 } /* Generic.Traceback */
.kc { color: #008000; font-weight: bold } /* Keyword.Constant */
.kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
.kn { color: #008000; font-weight: bold } /* Keyword.Namespace */
.kp { color: #003080; font-weight: bold } /* Keyword.Pseudo */
.kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
.kt { color: #303090; font-weight: bold } /* Keyword.Type */
.m { color: #6000E0; font-weight: bold } /* Literal.Number */
.s { background-color: #fff0f0 } /* Literal.String */
.na { color: #0000C0 } /* Name.Attribute */
.nb { color: #007020 } /* Name.Builtin */
.nc { color: #B00060; font-weight: bold } /* Name.Class */
.no { color: #003060; font-weight: bold } /* Name.Constant */
.nd { color: #505050; font-weight: bold } /* Name.Decorator */
.ni { color: #800000; font-weight: bold } /* Name.Entity */
.ne { color: #F00000; font-weight: bold } /* Name.Exception */
.nf { color: #0060B0; font-weight: bold } /* Name.Function */
.nl { color: #907000; font-weight: bold } /* Name.Label */
.nn { color: #0e84b5; font-weight: bold } /* Name.Namespace */
.nt { color: #007000 } /* Name.Tag */
.nv { color: #906030 } /* Name.Variable */
.ow { color: #000000; font-weight: bold } /* Operator.Word */
.w { color: #bbbbbb } /* Text.Whitespace */
.mf { color: #6000E0; font-weight: bold } /* Literal.Number.Float */
.mh { color: #005080; font-weight: bold } /* Literal.Number.Hex */
.mi { color: #0000D0; font-weight: bold } /* Literal.Number.Integer */
.mo { color: #4000E0; font-weight: bold } /* Literal.Number.Oct */
.sb { background-color: #fff0f0 } /* Literal.String.Backtick */
.sc { color: #0040D0 } /* Literal.String.Char */
.sd { color: #D04020 } /* Literal.String.Doc */
.s2 { background-color: #fff0f0 } /* Literal.String.Double */
.se { color: #606060; font-weight: bold; background-color: #fff0f0 } /* Literal.String.Escape */
.sh { background-color: #fff0f0 } /* Literal.String.Heredoc */
.si { background-color: #e0e0e0 } /* Literal.String.Interpol */
.sx { color: #D02000; background-color: #fff0f0 } /* Literal.String.Other */
.sr { color: #000000; background-color: #fff0ff } /* Literal.String.Regex */
.s1 { background-color: #fff0f0 } /* Literal.String.Single */
.ss { color: #A06000 } /* Literal.String.Symbol */
.bp { color: #007020 } /* Name.Builtin.Pseudo */
.vc { color: #306090 } /* Name.Variable.Class */
.vg { color: #d07000; font-weight: bold } /* Name.Variable.Global */
.vi { color: #3030B0 } /* Name.Variable.Instance */
.il { color: #0000D0; font-weight: bold } /* Literal.Number.Integer.Long */
