{% extends 'base.html' %}

{% block css %}
<link rel="stylesheet" href="{{ STATIC_URL }}timepiece/css/style.css" type="text/css" />
<link charset='UTF-8' rel="stylesheet" type="text/css" media="screen" href="{{ STATIC_URL }}css/books.css" />
{% endblock %}
